;;; -*- lexical-binding: t -*-

(defun my-what-cursor-position (&optional detail)
  "Like `what-cursor-position', but with important information only."
  (interactive "P")
  (if detail
      (what-cursor-position detail)
    (let* ((char (char-after))
           (char-info
            (cond
             ((null char) "")
             ((<= #x3fff80 char #x3fffff)
              (format "#x%02X (raw byte) " (logand char #xff)))
             (t
              (format "U+%04X %s "
                      char
                      (or (get-char-code-property char 'name)
                          (get-char-code-property char 'old-name)
                          "(undefined)")))))
           (beg (point-min))
           (end (point-max))
           (narrow (if (and (= beg 1) (= (1- end) (buffer-size)))
                       ""
                     (format " <%d-%d>" beg end))))
      (message "%spt=%d/%d%s col=%d"
               char-info
               (point) (buffer-size)
               narrow
               (current-column)))))

(global-set-key (kbd "C-x =") 'my-what-cursor-position)
